@@ -71,6 +71,16 @@ A009	7_09_BB	224
 A006	7_09_BB	224	 
 A013	7_09_BB	224	 "
 
+missing_single <-  "13	6	1	6											
+			7_09_BB											
+Ind	Pop	CHMFc4	CHMFc5	CHMFc12	SEA	SED	SEE	SEG	SEI	SEL	SEN	SEP	SEQ	SER
+A004	7_09_BB_A004	224	85	163	132	133	156	144	116	143	227	257	142	145
+A002	7_09_BB_A002	0	0	0	0	0	0	0	0	0	0	0	0	0
+A011	7_09_BB_A011	224	97	159	160	133	156	126	119	147	227	257	134	149
+A009	7_09_BB_A009	224	97	159	160	133	156	126	119	147	227	261	134	149
+A006	7_09_BB_A006	224	97	159	160	133	156	126	119	147	235	261	134	149
+A013	7_09_BB_A013	224	97	163	160	133	156	126	119	147	235	257	134	149"
+
 test_that("basic text connections work", {
 	gen <- read.genalex(textConnection(y), sep = "\t")
 	expect_equivalent(tab(gen), tab(monpop[1:6, drop = TRUE]))
@@ -124,6 +134,21 @@ Ind,Pop,RM127, ,RM22, ,RM22, ,RM127,
   expect_warning(read.genalex(textConnection(f)), "col 7: RM22 -> RM22_1")
 })
 
+test_that("missing samples do not shift strata", {
+  skip_on_cran()
+  expect_warning(ms <- read.genalex(textConnection(missing_single), sep = "\t"), "entirely non-type individual\\(s\\) deleted")
+  expect_equal(as.character(strata(ms)$Pop), as.character(pop(ms)))
+  expect_equal(rownames(strata(ms)), indNames(ms))
+})
+
+test_that("missing samples do not shift strata, even with duplicated names", {
+  skip_on_cran()
+  missing_single2 <- gsub("A004\t", "A011\t", missing_single)
+  expect_warning(ms <- read.genalex(textConnection(missing_single2), sep = "\t"), "duplicate labels detected")
+  expect_equal(as.character(strata(ms)$Pop), as.character(pop(ms)))
+  expect_equal(rownames(strata(ms)), indNames(ms))
+})
+
 test_that("improperly-formatted data causes an error", {
   skip_on_cran()
   msg <- "^.+?6 individuals.+?5 rows.+?Please inspect "
